tlslite.basedb.BaseDB

Package tlslite :: Module basedb :: Class BaseDB |
[hide private]
[frames] | no frames]

# Class BaseDB

source code

Known Subclasses:
  - verifierdb.VerifierDB

Instance Methods | [hide private]
bool |
__contains__(self, username) Check if the database contains the specified username. | source code
__delitem__(self, username) | source code
__getitem__(self, username) | source code
__init__(self, filename, type) | source code
__setitem__(self, username, value) | source code
check(self, username, param) | source code
create(self) Create a new on-disk database. | source code
list |
keys(self) Return a list of usernames in the database. | source code
open(self) Open a pre-existing on-disk database. | source code

Method Details | [hide private]

### __contains__(self, username) (In operator) | source code
Check if the database contains the specified username. Parameters: `username` (str) - The username to check for. Returns: bool True if the database contains the username, False otherwise.

### create(self) | source code
Create a new on-disk database. Raises: `anydbm.error` - If there's a problem creating the database.

### keys(self) | source code
Return a list of usernames in the database. Returns: list The usernames in the database.

### open(self) | source code
Open a pre-existing on-disk database. Raises: `anydbm.error` - If there's a problem opening the database. `ValueError` - If the database is not of the right type.